#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-1mM7b3nnDDrCNNVzLnJOQB
key:                  gitit-0.16-1mM7b3nnDDrCNNVzLnJOQB
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  7a5c0f41ae63f46f0cbeb0ca57936bc1
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-1mM7b3nnDDrCNNVzLnJOQB
depends:
    HStringTemplate-0.8.8-IP6vBLVmNnD7nISraKO3Fd
    HTTP-4000.5.0-LRnlYej8cZ6BZAupGk7JqK
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG base-4.18.2.1
    base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    blaze-html-0.9.2.0-npfK3H1ZuJH9Vz9ywDZve bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-JQRSNCEnYbnI9HSe8tZfIN
    feed-1.3.2.1-6BkXFsLVf959C3xE3w6x1X filepath-1.4.300.1
    filestore-0.6.5.1-9dzqFpicp3aDIOVyutfT7s ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-Kvm2PkZMIWPGyK5v5m6Qoc
    hoauth2-2.14.0-9zsuekyAFzFGwUEFhrEj65
    hslogger-1.3.2.0-BIrSd8Hic0SHfRAmfDqIH1
    http-client-tls-0.3.6.4-H3zfj6u59LA6yzNQrvZrZx
    http-conduit-2.3.9.1-EhOu3SIoVgTGe8LjY9FuRl
    json-0.11-Dk8HRpib8IrEFejxXondjx mtl-2.3.1
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    network-bsd-2.8.1.0-CHMLDNXllaZ5lauUIkGB8E
    network-uri-2.6.4.2-6IsL4l5xPlJ2SbjqeOZPL6
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-9WWjmNUa02UkaP5dbkbXm
    pandoc-3.6.1-7l2dfaSSLmDKjsPeY4dwBy
    pandoc-types-1.23.1.2-GnGOET1hVCD64BC9FEI4jc parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-2fto0SX8B0n5d0nC1pFLHo
    recaptcha-0.1.0.4-98PEBMi7r53A9YnZMCe4qb
    safe-0.3.21-KdE8f1g6p6v53Pxmzg6oHI
    skylighting-0.14.5-JmO3RZqxepk9hZnLKMq7v3
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE
    tagsoup-0.14.8-GmLkNVT7BtSIsZJwUcAvgD
    temporary-1.3-6srFELH6ZJ85EWwSBp1olQ text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-14nUH8YT7Z25UBrP1UVxjI
    url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    uuid-1.3.16.1-8Wpd3om6bCL87vO2yxvkz8 xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-FyMygpdJG0eLB74LAkEbeM
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-LYo3ZLEfX789u5CPPP8HuU
    zlib-0.7.1.0-EYn42Kcbw83G25OrlEVL7c

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

